@@ -24,8 +24,7 @@ from psutil.tests import get_test_subprocess
 from psutil.tests import HAS_BATTERY
 from psutil.tests import MEMORY_TOLERANCE
 from psutil.tests import reap_children
-from psutil.tests import retry_before_failing
-from psutil.tests import run_test_module_by_name
+from psutil.tests import retry_on_failure
 from psutil.tests import sh
 from psutil.tests import unittest
 from psutil.tests import which
@@ -73,7 +72,7 @@ def muse(field):
 
 
 @unittest.skipIf(not BSD, "BSD only")
-class BSDSpecificTestCase(unittest.TestCase):
+class BSDTestCase(unittest.TestCase):
     """Generic tests common to all BSD variants."""
 
     @classmethod
@@ -149,7 +148,7 @@ class BSDSpecificTestCase(unittest.TestCase):
 
 
 @unittest.skipIf(not FREEBSD, "FREEBSD only")
-class FreeBSDSpecificTestCase(unittest.TestCase):
+class FreeBSDProcessTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
@@ -159,21 +158,8 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
     def tearDownClass(cls):
         reap_children()
 
-    @staticmethod
-    def parse_swapinfo():
-        # the last line is always the total
-        output = sh("swapinfo -k").splitlines()[-1]
-        parts = re.split(r'\s+', output)
-
-        if not parts:
-            raise ValueError("Can't parse swapinfo: %s" % output)
-
-        # the size is in 1k units, so multiply by 1024
-        total, used, free = (int(p) * 1024 for p in parts[1:4])
-        return total, used, free
-
-    @retry_before_failing()
-    def test_proc_memory_maps(self):
+    @retry_on_failure()
+    def test_memory_maps(self):
         out = sh('procstat -v %s' % self.pid)
         maps = psutil.Process(self.pid).memory_maps(grouped=False)
         lines = out.split('\n')[1:]
@@ -187,17 +173,17 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
             if not map.path.startswith('['):
                 self.assertEqual(fields[10], map.path)
 
-    def test_proc_exe(self):
+    def test_exe(self):
         out = sh('procstat -b %s' % self.pid)
         self.assertEqual(psutil.Process(self.pid).exe(),
                          out.split('\n')[1].split()[-1])
 
-    def test_proc_cmdline(self):
+    def test_cmdline(self):
         out = sh('procstat -c %s' % self.pid)
         self.assertEqual(' '.join(psutil.Process(self.pid).cmdline()),
                          ' '.join(out.split('\n')[1].split()[2:]))
 
-    def test_proc_uids_gids(self):
+    def test_uids_gids(self):
         out = sh('procstat -s %s' % self.pid)
         euid, ruid, suid, egid, rgid, sgid = out.split('\n')[1].split()[2:8]
         p = psutil.Process(self.pid)
@@ -210,8 +196,8 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
         self.assertEqual(gids.effective, int(egid))
         self.assertEqual(gids.saved, int(sgid))
 
-    @retry_before_failing()
-    def test_proc_ctx_switches(self):
+    @retry_on_failure()
+    def test_ctx_switches(self):
         tested = []
         out = sh('procstat -r %s' % self.pid)
         p = psutil.Process(self.pid)
@@ -230,8 +216,8 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
         if len(tested) != 2:
             raise RuntimeError("couldn't find lines match in procstat out")
 
-    @retry_before_failing()
-    def test_proc_cpu_times(self):
+    @retry_on_failure()
+    def test_cpu_times(self):
         tested = []
         out = sh('procstat -r %s' % self.pid)
         p = psutil.Process(self.pid)
@@ -250,11 +236,31 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
         if len(tested) != 2:
             raise RuntimeError("couldn't find lines match in procstat out")
 
+
+@unittest.skipIf(not FREEBSD, "FREEBSD only")
+class FreeBSDSystemTestCase(unittest.TestCase):
+
+    @staticmethod
+    def parse_swapinfo():
+        # the last line is always the total
+        output = sh("swapinfo -k").splitlines()[-1]
+        parts = re.split(r'\s+', output)
+
+        if not parts:
+            raise ValueError("Can't parse swapinfo: %s" % output)
+
+        # the size is in 1k units, so multiply by 1024
+        total, used, free = (int(p) * 1024 for p in parts[1:4])
+        return total, used, free
+
     def test_cpu_frequency_against_sysctl(self):
         # Currently only cpu 0 is frequency is supported in FreeBSD
         # All other cores use the same frequency.
         sensor = "dev.cpu.0.freq"
-        sysctl_result = int(sysctl(sensor))
+        try:
+            sysctl_result = int(sysctl(sensor))
+        except RuntimeError:
+            self.skipTest("frequencies not supported by kernel")
         self.assertEqual(psutil.cpu_freq().current, sysctl_result)
 
         sensor = "dev.cpu.0.freq_levels"
@@ -269,37 +275,37 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
 
     # --- virtual_memory(); tests against sysctl
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_active(self):
         syst = sysctl("vm.stats.vm.v_active_count") * PAGESIZE
         self.assertAlmostEqual(psutil.virtual_memory().active, syst,
                                delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_inactive(self):
         syst = sysctl("vm.stats.vm.v_inactive_count") * PAGESIZE
         self.assertAlmostEqual(psutil.virtual_memory().inactive, syst,
                                delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_wired(self):
         syst = sysctl("vm.stats.vm.v_wire_count") * PAGESIZE
         self.assertAlmostEqual(psutil.virtual_memory().wired, syst,
                                delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_cached(self):
         syst = sysctl("vm.stats.vm.v_cache_count") * PAGESIZE
         self.assertAlmostEqual(psutil.virtual_memory().cached, syst,
                                delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_free(self):
         syst = sysctl("vm.stats.vm.v_free_count") * PAGESIZE
         self.assertAlmostEqual(psutil.virtual_memory().free, syst,
                                delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
+    @retry_on_failure()
     def test_vmem_buffers(self):
         syst = sysctl("vfs.bufspace")
         self.assertAlmostEqual(psutil.virtual_memory().buffers, syst,
@@ -313,42 +319,42 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
         self.assertEqual(psutil.virtual_memory().total, num)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_active(self):
         num = muse('Active')
         self.assertAlmostEqual(psutil.virtual_memory().active, num,
                                delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_inactive(self):
         num = muse('Inactive')
         self.assertAlmostEqual(psutil.virtual_memory().inactive, num,
                                delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_wired(self):
         num = muse('Wired')
         self.assertAlmostEqual(psutil.virtual_memory().wired, num,
                                delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_cached(self):
         num = muse('Cache')
         self.assertAlmostEqual(psutil.virtual_memory().cached, num,
                                delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_free(self):
         num = muse('Free')
         self.assertAlmostEqual(psutil.virtual_memory().free, num,
                                delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(not MUSE_AVAILABLE, "muse not installed")
-    @retry_before_failing()
+    @retry_on_failure()
     def test_muse_vmem_buffers(self):
         num = muse('Buffer')
         self.assertAlmostEqual(psutil.virtual_memory().buffers, num,
@@ -367,8 +373,9 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
                                sysctl('vm.stats.sys.v_soft'), delta=1000)
 
     def test_cpu_stats_syscalls(self):
+        # pretty high tolerance but it looks like it's OK.
         self.assertAlmostEqual(psutil.cpu_stats().syscalls,
-                               sysctl('vm.stats.sys.v_syscall'), delta=1000)
+                               sysctl('vm.stats.sys.v_syscall'), delta=100000)
 
     # def test_cpu_stats_traps(self):
     #    self.assertAlmostEqual(psutil.cpu_stats().traps,
@@ -451,7 +458,10 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
         for cpu in range(num_cpus):
             sensor = "dev.cpu.%s.temperature" % cpu
             # sysctl returns a string in the format 46.0C
-            sysctl_result = int(float(sysctl(sensor)[:-1]))
+            try:
+                sysctl_result = int(float(sysctl(sensor)[:-1]))
+            except RuntimeError:
+                self.skipTest("temperatures not supported by kernel")
             self.assertAlmostEqual(
                 psutil.sensors_temperatures()["coretemp"][cpu].current,
                 sysctl_result, delta=10)
@@ -468,7 +478,7 @@ class FreeBSDSpecificTestCase(unittest.TestCase):
 
 
 @unittest.skipIf(not OPENBSD, "OPENBSD only")
-class OpenBSDSpecificTestCase(unittest.TestCase):
+class OpenBSDTestCase(unittest.TestCase):
 
     def test_boot_time(self):
         s = sysctl('kern.boottime')
@@ -483,11 +493,11 @@ class OpenBSDSpecificTestCase(unittest.TestCase):
 
 
 @unittest.skipIf(not NETBSD, "NETBSD only")
-class NetBSDSpecificTestCase(unittest.TestCase):
+class NetBSDTestCase(unittest.TestCase):
 
     @staticmethod
     def parse_meminfo(look_for):
-        with open('/proc/meminfo', 'rb') as f:
+        with open('/proc/meminfo', 'rt') as f:
             for line in f:
                 if line.startswith(look_for):
                     return int(line.split()[1]) * 1024
@@ -550,4 +560,5 @@ class NetBSDSpecificTestCase(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    run_test_module_by_name(__file__)
+    from psutil.tests.runner import run
+    run(__file__)
